multidim.PointCloud.witnessed_barycenters — GDA Toolbox v1.0 Manual

# multidim.PointCloud.witnessed_barycenters

`PointCloud.` `witnessed_barycenters`(k)

  Build the PointCloud of k-witnessed barycenters, weighted by distance-to-measure. This calls `nearest_neighbors()` with argument `(k-1)`, which can be slow.

  Parameters: | k : int How many vertices for each witnessed barycenter. That is, use the (k-1) nearest neighbors, along with the vertex itself.
  Returns: | pc : `PointCloud` A pointcloud whose 0-cells are the witnessed barycenters, and whose 1-cells are the edges between those barycenters, all weighted by the notion of distance to a measure.

#### Previous topic

multidim.PointCloud.unique_with_multiplicity

#### Next topic

multidim.covertree.CoverTree